@@ -1,6 +1,6 @@
 from django.conf.urls import patterns, url
 
-urlpatterns = patterns('tracking.views',
+urlpatterns = patterns(
+    'tracking.views',
     url(r'^$', 'dashboard', name='tracking-dashboard'),
-    url(r'^dashboard/$', 'stats'),
 )
